# -*- coding: utf-8 -*-
#  Copyright (C) 2006, 2007, 2008, 2010 Stewart Adam
#  This file is part of fwfstab.

#  fwfstab is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.

#  fwfstab is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with fwfstab; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""
This module deals with the detection of disks and disk information, such as
disk model, make, geometry, etc.
"""
import os
try:
  import parted
  import _ped
  autodetect_capable = True
except: # for whatever reason...
  autodetect_capable = False
from fwfstab.i18n import _

def getHardDrives():
  """Return a list of all hard drive names"""
  disks = []
  _ped.device_probe_all()
  try:
    ped_device = _ped.device_get_next()
    device = parted.device.Device(path=ped_device.path)
    disk = parted.disk.Disk(device)
    disks.append(disk)
    while True:
      try:
        ped_device = _ped.device_get_next(ped_device)
        device = parted.device.Device(path=ped_device.path)
        disk = parted.disk.Disk(device)
        disks.append(disk)
      except IndexError:
        break
  except IndexError:
    pass
  return disks

def getPartitionNodeName(partition):
  """Wrapper to get a partition's node name that properly handles LVM PVs"""
  if partition.disk.device.type == parted.DEVICE_DM:
    # pyparted incorrectly determines the partition paths for DM devices
    return partition.disk.device.path
  return os.path.join("/dev", partition.getDeviceNodeName())

def getPartitionIsMountable(partition):
  """Determines if the partition is mountable and suitable for display in the UI"""
  # partition cannot be LVM physical volume, extended partition, free space,
  # RAID volume or a partition with no filesystem
  if partition.type in [parted.PARTITION_FREESPACE, parted.PARTITION_EXTENDED] \
     or partition.getFlag(parted.PARTITION_RAID) == 1 \
     or partition.getFlag(parted.PARTITION_LVM) == 1 \
     or partition.fileSystem == None:
     return False
  return True

def getPartitionType(partition):
  """Return the FS on a partition"""
  if partition.type == parted.PARTITION_FREESPACE:
    fs_type = _("Free space")
  elif partition.type == parted.PARTITION_EXTENDED:
    fs_type = _("Extended")
  elif partition.getFlag(parted.PARTITION_RAID) == 1:
    fs_type = _("Software RAID component")
  elif partition.getFlag(parted.PARTITION_LVM) == 1:
    fs_type = _("LVM Physical Volume")
  elif partition.fileSystem != None:
    fs_type = partition.fileSystem.type
  else:
    fs_type = _("none")
  if fs_type.startswith("linux-swap"):
    fs_type = "swap"
  return fs_type
